@@ -55,7 +55,7 @@ impl TestEnv {
     /// Write `content` to "config.toml" in the `config_dir` directory
     fn write_config(&self, content: impl AsRef<str>) {
         let config_file_name = self.config_dir.path().join("config.toml");
-        println!("Config path: {:?}", config_file_name);
+        println!("Config path: {config_file_name:?}");
 
         let mut config_file = File::create(&config_file_name).unwrap();
         config_file.write_all(content.as_ref().as_bytes()).unwrap();
@@ -76,7 +76,7 @@ impl TestEnv {
             .join(os);
         create_dir_all(&dir).unwrap();
 
-        let mut file = File::create(&dir.join(format!("{}.md", name))).unwrap();
+        let mut file = File::create(dir.join(format!("{name}.md"))).unwrap();
         file.write_all(contents.as_bytes()).unwrap();
     }
 
@@ -84,7 +84,7 @@ impl TestEnv {
     fn add_page_entry(&self, name: &str, contents: &str) {
         let dir = self.custom_pages_dir.path();
         create_dir_all(dir).unwrap();
-        let mut file = File::create(&dir.join(format!("{}.page", name))).unwrap();
+        let mut file = File::create(dir.join(format!("{name}.page.md"))).unwrap();
         file.write_all(contents.as_bytes()).unwrap();
     }
 
@@ -92,7 +92,7 @@ impl TestEnv {
     fn add_patch_entry(&self, name: &str, contents: &str) {
         let dir = self.custom_pages_dir.path();
         create_dir_all(dir).unwrap();
-        let mut file = File::create(&dir.join(format!("{}.patch", name))).unwrap();
+        let mut file = File::create(dir.join(format!("{name}.patch.md"))).unwrap();
         file.write_all(contents.as_bytes()).unwrap();
     }
 
@@ -120,7 +120,7 @@ impl TestEnv {
             build = build.arg("--no-default-features");
         }
         if !self.features.is_empty() {
-            build = build.arg(&format!("--feature {}", self.features.join(",")));
+            build = build.arg(format!("--feature {}", self.features.join(",")));
         }
         let run = build.run().unwrap();
         let mut cmd = run.command();
@@ -426,7 +426,7 @@ fn _test_correct_rendering(
 
     // Create input file
     let file_path = testenv.input_dir.path().join(filename);
-    println!("Testfile path: {:?}", file_path);
+    println!("Testfile path: {file_path:?}");
     let mut file = File::create(&file_path).unwrap();
     file.write_all(input_file.as_bytes()).unwrap();
 
@@ -501,7 +501,7 @@ fn test_correct_rendering_with_config() {
     // Setup config file
     // TODO should be config::CONFIG_FILE_NAME
     let config_file_path = testenv.config_dir.path().join("config.toml");
-    println!("Config path: {:?}", config_file_path);
+    println!("Config path: {config_file_path:?}");
 
     let mut config_file = File::create(&config_file_path).unwrap();
     config_file
@@ -510,7 +510,7 @@ fn test_correct_rendering_with_config() {
 
     // Create input file
     let file_path = testenv.input_dir.path().join("inkscape-v2.md");
-    println!("Testfile path: {:?}", file_path);
+    println!("Testfile path: {file_path:?}");
 
     let mut file = File::create(&file_path).unwrap();
     file.write_all(include_bytes!("inkscape-v2.md")).unwrap();
@@ -562,6 +562,71 @@ fn test_pager_flag_enable() {
         .success();
 }
 
+#[test]
+fn test_multiple_platform_command_search() {
+    let testenv = TestEnv::new();
+    testenv.add_os_entry("linux", "linux-only", "this command only exists for linux");
+    testenv.add_os_entry(
+        "linux",
+        "windows-and-linux",
+        "# windows-and-linux \n\n > linux version",
+    );
+    testenv.add_os_entry(
+        "windows",
+        "windows-and-linux",
+        "# windows-and-linux \n\n > windows version",
+    );
+
+    testenv
+        .command()
+        .args(["--platform", "windows", "--platform", "linux", "linux-only"])
+        .assert()
+        .success();
+
+    // test order of platforms supplied if preserved
+    testenv
+        .command()
+        .args([
+            "--platform",
+            "windows",
+            "--platform",
+            "linux",
+            "windows-and-linux",
+        ])
+        .assert()
+        .success()
+        .stdout(contains("windows version"));
+
+    testenv
+        .command()
+        .args([
+            "--platform",
+            "linux",
+            "--platform",
+            "windows",
+            "windows-and-linux",
+        ])
+        .assert()
+        .success()
+        .stdout(contains("linux version"));
+}
+
+#[test]
+fn test_multiple_platform_command_search_not_found() {
+    let testenv = TestEnv::new();
+    testenv.add_os_entry(
+        "windows",
+        "windows-only",
+        "this command only exists for Windows",
+    );
+
+    testenv
+        .command()
+        .args(["--platform", "macos", "--platform", "linux", "windows-only"])
+        .assert()
+        .stderr(contains("Page `windows-only` not found in cache."));
+}
+
 #[test]
 fn test_list_flag_rendering() {
     let testenv = TestEnv::new();
@@ -604,6 +669,79 @@ fn test_list_flag_rendering() {
         .stdout("bar\nbaz\nfaz\nfiz\nfoo\nqux\n");
 }
 
+#[test]
+fn test_multi_platform_list_flag_rendering() {
+    let testenv = TestEnv::new();
+
+    // set custom pages directory
+    testenv.write_config(format!(
+        "[directories]\ncustom_pages_dir = '{}'",
+        testenv.custom_pages_dir.path().to_str().unwrap()
+    ));
+
+    testenv.add_entry("common", "");
+
+    testenv
+        .command()
+        .args(["--list"])
+        .assert()
+        .success()
+        .stdout("common\n");
+
+    testenv
+        .command()
+        .args(["--platform", "linux", "--list"])
+        .assert()
+        .success()
+        .stdout("common\n");
+
+    testenv
+        .command()
+        .args(["--platform", "windows", "--list"])
+        .assert()
+        .success()
+        .stdout("common\n");
+
+    testenv.add_os_entry("linux", "rm", "");
+    testenv.add_os_entry("linux", "ls", "");
+    testenv.add_os_entry("windows", "del", "");
+    testenv.add_os_entry("windows", "dir", "");
+    testenv.add_os_entry("linux", "winux", "");
+    testenv.add_os_entry("windows", "winux", "");
+
+    // test `--list` for `--platform linux` by itself
+    testenv
+        .command()
+        .args(["--platform", "linux", "--list"])
+        .assert()
+        .success()
+        .stdout("common\nls\nrm\nwinux\n");
+
+    // test `--list` for `--platform windows` by itself
+    testenv
+        .command()
+        .args(["--platform", "windows", "--list"])
+        .assert()
+        .success()
+        .stdout("common\ndel\ndir\nwinux\n");
+
+    // test `--list` for `--platform linux --platform windows`
+    testenv
+        .command()
+        .args(["--platform", "linux", "--platform", "windows", "--list"])
+        .assert()
+        .success()
+        .stdout("common\ndel\ndir\nls\nrm\nwinux\n");
+
+    // test `--list` for `--platform windows --platform linux`
+    testenv
+        .command()
+        .args(["--platform", "linux", "--platform", "windows", "--list"])
+        .assert()
+        .success()
+        .stdout("common\ndel\ndir\nls\nrm\nwinux\n");
+}
+
 #[test]
 fn test_autoupdate_cache() {
     let testenv = TestEnv::new();
@@ -620,7 +758,7 @@ fn test_autoupdate_cache() {
     let cache_file_path = testenv.cache_dir.path().join(TLDR_PAGES_DIR);
 
     // Activate automatic updates, set the auto-update interval to 24 hours
-    let mut config_file = File::create(&config_file_path).unwrap();
+    let mut config_file = File::create(config_file_path).unwrap();
     config_file
         .write_all(b"[updates]\nauto_update = true\nauto_update_interval_hours = 24")
         .unwrap();
@@ -660,7 +798,7 @@ fn test_autoupdate_cache() {
     check_cache_updated(false);
 }
 
-/// End-end test to ensure .page files overwrite pages in cache_dir
+/// End-end test to ensure .page.md files overwrite pages in cache_dir
 #[test]
 fn test_custom_page_overwrites() {
     let testenv = TestEnv::new();
@@ -673,7 +811,7 @@ fn test_custom_page_overwrites() {
 
     // Add file that should be ignored to the cache dir
     testenv.add_entry("inkscape-v2", "");
-    // Add .page file to custome_pages_dir
+    // Add .page.md file to custom_pages_dir
     testenv.add_page_entry("inkscape-v2", include_str!("inkscape-v2.md"));
 
     // Load expected output
@@ -687,7 +825,7 @@ fn test_custom_page_overwrites() {
         .stdout(diff(expected));
 }
 
-/// End-End test to ensure that .patch files are appended to pages in the cache_dir
+/// End-End test to ensure that .patch.md files are appended to pages in the cache_dir
 #[test]
 fn test_custom_patch_appends_to_common() {
     let testenv = TestEnv::new();
@@ -700,8 +838,8 @@ fn test_custom_patch_appends_to_common() {
 
     // Add page to the cache dir
     testenv.add_entry("inkscape-v2", include_str!("inkscape-v2.md"));
-    // Add .page file to custome_pages_dir
-    testenv.add_patch_entry("inkscape-v2", include_str!("inkscape-v2.patch"));
+    // Add .page.md file to custom_pages_dir
+    testenv.add_patch_entry("inkscape-v2", include_str!("inkscape-v2.patch.md"));
 
     // Load expected output
     let expected = include_str!("inkscape-patched-no-color.expected");
@@ -714,7 +852,7 @@ fn test_custom_patch_appends_to_common() {
         .stdout(diff(expected));
 }
 
-/// End-End test to ensure that .patch files are not appended to .page files in the custom_pages_dir
+/// End-End test to ensure that .patch.md files are not appended to .page.md files in the custom_pages_dir
 /// Maybe this interaction should change but I put this test here for the coverage
 #[test]
 fn test_custom_patch_does_not_append_to_custom() {
@@ -730,8 +868,8 @@ fn test_custom_patch_does_not_append_to_custom() {
 
     // Add page to the cache dir
     testenv.add_page_entry("inkscape-v2", include_str!("inkscape-v2.md"));
-    // Add .page file to custome_pages_dir
-    testenv.add_patch_entry("inkscape-v2", include_str!("inkscape-v2.patch"));
+    // Add .page.md file to custom_pages_dir
+    testenv.add_patch_entry("inkscape-v2", include_str!("inkscape-v2.patch.md"));
 
     // Load expected output
     let expected = include_str!("inkscape-default-no-color.expected");
